from setuptools import setup


setup(
    name='sqlLibraryNabeel',
    version='0.0.1',
    description = 'Process json and convert it into dataframes',
    py_modules=["sheets","sqlConverter"],
    package_dir={'':'src'},
    install_requires=[
        'autopep8~=1.5.4',
        'cachetools~=4.1.1',
        'certifi~=2020.6.20',
        'chardet~=3.0.4',
        'click~=7.1.2',
        'colorama~=0.4.4',
        'Flask~=1.1.2',
        'google-api-core~=1.23.0',
        'google-api-python-client~=1.12.5',
        'google-auth~=1.23.0',
        'google-auth-httplib2~=0.0.4',
        'google-auth-oauthlib~=0.4.2',
        'googleapis-common-protos~=1.52.0',
        'gspread~=3.6.0',
        'httplib2~=0.18.1',
        'idna~=2.10',
        'isort~=5.6.4',
        'itsdangerous~=1.1.0',
        'Jinja2~=2.11.2',
        'lazy-object-proxy~=1.4.3',
        'MarkupSafe~=1.1.1',
        'mccabe~=0.6.1',
        'numpy~=1.19.3',
        'oauth2client~=4.1.3',
        'oauthlib~=3.1.0',
        'pandas~=1.1.4',
        'pandasql~=0.7.3',
        'protobuf~=3.13.0',
        'pyasn1~=0.4.8',
        'pyasn1-modules~=0.2.8',
        'pycodestyle~=2.6.0',
        'pylint~=2.6.0',
        'python-dateutil~=2.8.1',
        'pytz~=2020.1',
        'requests~=2.24.0',
        'requests-oauthlib~=1.3.0',
        'rsa~=4.6',
        'Sheets~=0.6',
        'six~=1.15.0',
        'SQLAlchemy~=1.3.20',
        'toml~=0.10.2',
        'Unidecode~=1.1.1',
        'uritemplate~=3.0.1',
        'urllib3~=1.25.11',
        'Werkzeug~=1.0.1',
        'wrapt~=1.12.1'
    ],
    url='https://github.com/#',
    author='Rusab Naeem',
    author_email='rusab.khan@lyftron.com'

)